@@ -1,5 +1,5 @@
 
-from __future__ import division
+from __future__ import division, print_function
 
 import os
 import sys
@@ -9,6 +9,7 @@ from pprint import pprint, pformat
 import time
 from subprocess import Popen, PIPE
 import hashlib
+from base64 import b64encode, b64decode, b16encode
 
 from tomcrypt import prng
 from tomcrypt.rsa import *
@@ -20,7 +21,7 @@ class TestRSA(TestCase):
     def test_key_size_for_payload(self):
         payload = 100
         size = key_size_for_payload(payload)
-        key = generate_key(size)
+        key = Key(size)
         self.assertEqual(size, key.size)
         self.assertEqual(payload, key.max_payload())
         
@@ -30,6 +31,31 @@ class TestRSA(TestCase):
         self.assertTrue('BEGIN PUBLIC' in key.as_string('public'))
         self.assertTrue('BEGIN PUBLIC' in key.public.as_string())
 
+    def test_no_padding(self):
+        key = Key(1024)
+        ct1 = key.encrypt(b"hello", padding="none")
+        ct2 = key.encrypt(b"hello", padding="none")
+        pt = key.decrypt(ct1, padding="none").lstrip(b'\0')
+        self.assertEqual(ct1, ct2)
+        self.assertEqual(pt, b"hello")
+
+    def test_encrypt(self):
+        key = Key(1024)
+        pt1 = b"hello world"
+        ct1 = key.encrypt(pt1)
+        ct2 = key.encrypt(pt1)
+        pt2 = key.decrypt(ct1)
+
+        self.assertEqual(pt1, pt2)
+        self.assertNotEqual(ct1, ct2)
+
+    def test_sign(self):
+        key = Key(1024)
+        msg = b"hello world"
+        sig = key.sign(msg)
+        self.assertTrue(key.verify(msg, sig))
+        # Not testing failure.
+
         
 if __name__ == '__main__':
     
@@ -37,8 +63,6 @@ if __name__ == '__main__':
     
     start_time = time.time()
     
-    print 100, k.max_payload()
-    
     key = Key('''-----BEGIN RSA PRIVATE KEY-----
     MIICXwIBAAKBgQv9V1DrxfhDt56rC1/i18HJE6x/SLs2xu5IDySxI0xhme8U6T6w
     Ess275MacdQMSZh5MJl+8YRErwx6zOilDz8y2GDqKrsuMgAodkvfKAeQlQZp+IPZ
@@ -55,8 +79,8 @@ if __name__ == '__main__':
     ioKaum9hlRf3nuXxmSfqv7iXozX6xfrYncjLKbBn/hPhWp8=
     -----END RSA PRIVATE KEY-----''')
     
-    print '1028?', key.size
-    print key.encrypt('hello').encode('base64')
+    print('1028?', key.size)
+    print(b64encode(key.encrypt(b'hello')))
     
     private = Key('''-----BEGIN RSA PRIVATE KEY-----
     MIICXQIBAAKBgQC9mcyIFoka73NeECWjCHxr5ssMU5MBPpV2AMYHmtB8qiO5gmiU
@@ -83,22 +107,22 @@ if __name__ == '__main__':
     -----END PUBLIC KEY-----
     ''')
     
-    print 'max_payload', private.max_payload(), public.max_payload()
+    print('max_payload', private.max_payload(), public.max_payload())
     
-    pt = 'Hello, world.'
+    pt = b'Hello, world.'
     ct = public.encrypt(pt)
-    print 'ct len', len(ct)
+    print('ct len', len(ct))
     pt2 = private.decrypt(ct)
     
-    print repr(pt2)
+    print(repr(pt2))
     
     pt = pt * 1000
     sig = private.sign(pt)
-    print repr(sig)
-    print public.verify(pt, sig)
+    print(repr(sig))
+    print(public.verify(pt, sig))
     
     # print 'bad - pre'
     #  bad = Key('bad')
     #  print 'bad - post'
     
-    print 'Ran all tests in %.2fms' % (1000 * (time.time() - start_time))
\ No newline at end of file
+    print('Ran all tests in %.2fms' % (1000 * (time.time() - start_time)))
